@@ -4,7 +4,6 @@
 
 #include "internal.h"
 #include "fw_fcp.h"
-#include "hinawa_enum_types.h"
 
 /**
  * SECTION:fw_fcp
@@ -53,9 +52,9 @@ enum avc_status {
 
 struct fcp_transaction {
 	const guint8 *req_frame;
-	guint req_frame_size;
+	gsize req_frame_size;
 	guint8 *resp_frame;
-	guint resp_frame_size;
+	gsize resp_frame_size;
 	GCond cond;
 	GMutex mutex;
 };
@@ -72,6 +71,7 @@ G_DEFINE_TYPE_WITH_PRIVATE(HinawaFwFcp, hinawa_fw_fcp, HINAWA_TYPE_FW_RESP)
 /* This object has one property. */
 enum fw_fcp_prop_type {
 	FW_FCP_PROP_TYPE_TIMEOUT = 1,
+	FW_FCP_PROP_TYPE_IS_BOUND,
 	FW_FCP_PROP_TYPE_COUNT,
 };
 static GParamSpec *fw_fcp_props[FW_FCP_PROP_TYPE_COUNT] = { NULL, };
@@ -86,6 +86,9 @@ static void fw_fcp_get_property(GObject *obj, guint id, GValue *val,
 	case FW_FCP_PROP_TYPE_TIMEOUT:
 		g_value_set_uint(val, priv->timeout);
 		break;
+	case FW_FCP_PROP_TYPE_IS_BOUND:
+		g_value_set_boolean(val, priv->node != NULL);
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID(obj, id, spec);
 		break;
@@ -134,9 +137,15 @@ static void hinawa_fw_fcp_class_init(HinawaFwFcpClass *klass)
 		g_param_spec_uint("timeout", "timeout",
 				  "An elapse to expire waiting for response "
 				  "by msec unit.",
-				  10, UINT_MAX,
+				  10, G_MAXUINT,
 				  200,
 				  G_PARAM_READWRITE | G_PARAM_CONSTRUCT);
+	fw_fcp_props[FW_FCP_PROP_TYPE_IS_BOUND] =
+		g_param_spec_boolean("is-bound", "is-bound",
+				     "Whether this protocol is bound to any "
+				     "instance of HinawaFwNode.",
+				     FALSE,
+				     G_PARAM_READABLE);
 
 	g_object_class_install_properties(gobject_class,
 					  FW_FCP_PROP_TYPE_COUNT,
@@ -185,8 +194,8 @@ HinawaFwFcp *hinawa_fw_fcp_new(void)
  * Since: 1.4.
  */
 void hinawa_fw_fcp_transaction(HinawaFwFcp *self,
-			       const guint8 *req_frame, guint req_frame_size,
-			       guint8 *const *resp_frame, guint *resp_frame_size,
+			       const guint8 *req_frame, gsize req_frame_size,
+			       guint8 *const *resp_frame, gsize *resp_frame_size,
 			       GError **exception)
 {
 	HinawaFwFcpPrivate *priv;
@@ -277,37 +286,13 @@ end:
 	g_clear_object(&req);
 }
 
-/**
- * hinawa_fw_fcp_transact:
- * @self: A #HinawaFwFcp
- * @req_frame:  (element-type guint8) (array) (in): a byte frame for request
- * @resp_frame: (element-type guint8) (array) (out caller-allocates): a byte
- *		frame for response
- * @exception: A #GError
- *
- * Execute fCP transaction.
- * Deprecated: 1.4: Use hinawa_fw_fcp_transaction() instead,
- */
-void hinawa_fw_fcp_transact(HinawaFwFcp *self,
-			    GByteArray *req_frame, GByteArray *resp_frame,
-			    GError **exception)
-{
-	// Some vendor specific FCP transaction has such response that the
-	// size does not equal to the size of request...
-	g_byte_array_set_size(resp_frame, FCP_MAXIMUM_FRAME_BYTES);
-
-	hinawa_fw_fcp_transaction(self, req_frame->data, req_frame->len,
-				  &(resp_frame->data), &(resp_frame->len),
-				  exception);
-}
-
 static HinawaFwRcode handle_response(HinawaFwResp *resp, HinawaFwTcode tcode)
 {
 	HinawaFwFcp *self = HINAWA_FW_FCP(resp);
 	HinawaFwFcpPrivate *priv = hinawa_fw_fcp_get_instance_private(self);
 	struct fcp_transaction *trans;
 	const guint8 *req_frame;
-	guint length;
+	gsize length;
 	GList *entry;
 
 	g_mutex_lock(&priv->transactions_mutex);
@@ -395,41 +380,3 @@ void hinawa_fw_fcp_unbind(HinawaFwFcp *self)
 		priv->node = NULL;
 	}
 }
-
-/**
- * hinawa_fw_fcp_listen:
- * @self: A #HinawaFwFcp
- * @unit: A #HinawaFwUnit
- * @exception: A #GError
- *
- * Start to listen to FCP responses.
- *
- * Deprecated: 1.4: Use hinawa_fw_fcp_bind() with an instance of HinawaFwNode,
- *		    instead.
- */
-void hinawa_fw_fcp_listen(HinawaFwFcp *self, HinawaFwUnit *unit,
-			  GError **exception)
-{
-	HinawaFwNode *node;
-
-	g_return_if_fail(HINAWA_IS_FW_FCP(self));
-
-	hinawa_fw_unit_get_node(unit, &node);
-
-	g_object_ref(node);
-	hinawa_fw_fcp_bind(self, node, exception);
-	g_object_unref(node);
-}
-
-/**
- * hinawa_fw_fcp_unlisten:
- * @self: A #HinawaFwFcp
- *
- * Stop to listen to FCP responses.
- *
- * Deprecated: 1.4: Use hinawa_fw_fcp_unbind(), instead.
- */
-void hinawa_fw_fcp_unlisten(HinawaFwFcp *self)
-{
-	hinawa_fw_fcp_unbind(self);
-}
