@@ -34,7 +34,7 @@ static GParamSpec *fw_req_props[FW_REQ_PROP_TYPE_COUNT] = { NULL, };
 struct _HinawaFwReqPrivate {
 	guint timeout;
 	guint8 *frame;
-	guint length;
+	gsize length;
 
 	guint rcode;
 	GMutex mutex;
@@ -108,7 +108,7 @@ static void hinawa_fw_req_class_init(HinawaFwReqClass *klass)
 	fw_req_props[FW_REQ_PROP_TYPE_TIMEOUT] =
 		g_param_spec_uint("timeout", "timeout",
 				  "An elapse to expire waiting for response by ms unit.",
-				  10, UINT_MAX,
+				  10, G_MAXUINT,
 				  200,
 				  G_PARAM_READWRITE | G_PARAM_CONSTRUCT);
 
@@ -159,8 +159,8 @@ HinawaFwReq *hinawa_fw_req_new(void)
  * Since: 1.4.
  */
 void hinawa_fw_req_transaction(HinawaFwReq *self, HinawaFwNode *node,
-			       HinawaFwTcode tcode, guint64 addr, guint length,
-			       guint8 *const *frame, guint *frame_size,
+			       HinawaFwTcode tcode, guint64 addr, gsize length,
+			       guint8 *const *frame, gsize *frame_size,
 			       GError **exception)
 {
 	struct fw_cdev_send_request req = {0};
@@ -271,6 +271,7 @@ void hinawa_fw_req_transaction(HinawaFwReq *self, HinawaFwNode *node,
 	g_mutex_unlock(&priv->mutex);
 
 	if (priv->rcode == G_MAXUINT) {
+		hinawa_fw_node_invalidate_transaction(node, self);
 		raise(exception, ETIMEDOUT);
 		goto end;
 	}
@@ -291,94 +292,7 @@ end:
 	g_object_unref(node);
 }
 
-/**
- * hinawa_fw_req_write:
- * @self: A #HinawaFwReq
- * @unit: A #HinawaFwUnit
- * @addr: A destination address of target device
- * @frame: (element-type guint8) (array) (in): a 8bit array
- * @exception: A #GError
- *
- * Execute write transactions to the given unit.
- * Deprecated: 1.4: Use hinawa_fw_req_transaction() instead.
- */
-void hinawa_fw_req_write(HinawaFwReq *self, HinawaFwUnit *unit, guint64 addr,
-			 GByteArray *frame, GError **exception)
-{
-	HinawaFwNode *node;
-	int tcode;
-
-	if (frame->len == 4 && !(addr & 0x03))
-		tcode = TCODE_WRITE_QUADLET_REQUEST;
-	else
-		tcode = TCODE_WRITE_BLOCK_REQUEST;
-
-	hinawa_fw_unit_get_node(unit, &node);
-	g_object_ref(node);
-	hinawa_fw_req_transaction(self, node, tcode, addr, frame->len,
-				  &(frame->data), &(frame->len), exception);
-	g_object_unref(node);
-}
-
-/**
- * hinawa_fw_req_read:
- * @self: A #HinawaFwReq
- * @unit: A #HinawaFwUnit
- * @addr: A destination address of target device
- * @frame: (element-type guint8) (array) (out caller-allocates): a 8bit array
- * @length: the number of bytes to read
- * @exception: A #GError
- *
- * Execute read transaction to the given unit.
- * Deprecated: 1.4: Use hinawa_fw_req_transaction() instead.
- */
-void hinawa_fw_req_read(HinawaFwReq *self, HinawaFwUnit *unit, guint64 addr,
-			GByteArray *frame, guint length, GError **exception)
-{
-	HinawaFwNode *node;
-	int tcode;
-
-	if (length == 4 && !(addr & 0x03))
-		tcode = TCODE_READ_QUADLET_REQUEST;
-	else
-		tcode = TCODE_READ_BLOCK_REQUEST;
-
-	g_byte_array_set_size(frame, length);
-
-	hinawa_fw_unit_get_node(unit, &node);
-	g_object_ref(node);
-	hinawa_fw_req_transaction(self, node, tcode, addr, frame->len,
-				  &(frame->data), &(frame->len), exception);
-	g_object_unref(node);
-}
-
-/**
- * hinawa_fw_req_lock:
- * @self: A #HinawaFwReq
- * @unit: A #HinawaFwUnit
- * @addr: A destination address of target device
- * @frame: (element-type guint8) (array) (inout): a 8bit array
- * @lock_tcode: One of #HinawaFwTcode enumerator for lock operation.
- * @exception: A #GError
- *
- * Execute lock transaction to the given unit.
- * Deprecated: 1.4: Use hinawa_fw_req_transaction() instead.
- */
-void hinawa_fw_req_lock(HinawaFwReq *self, HinawaFwUnit *unit,
-			guint64 addr, GByteArray **frame,
-			HinawaFwTcode lock_tcode, GError **exception)
-{
-	HinawaFwNode *node;
-	guint length = (*frame)->len / 2;
-
-	hinawa_fw_unit_get_node(unit, &node);
-	g_object_ref(node);
-	hinawa_fw_req_transaction(self, node, lock_tcode, addr, length,
-				&((*frame)->data), &((*frame)->len), exception);
-	g_object_unref(node);
-}
-
-/* NOTE: For HinawaFwUnit, internal. */
+// NOTE: For HinawaFwNode, internal.
 void hinawa_fw_req_handle_response(HinawaFwReq *self,
 				   struct fw_cdev_event_response *event)
 {
@@ -393,7 +307,7 @@ void hinawa_fw_req_handle_response(HinawaFwReq *self,
 
 	/* Copy transaction frame if needed. */
 	if (priv->frame && priv->length > 0) {
-		guint length = MIN(priv->length, event->length);
+		gsize length = MIN(priv->length, event->length);
 		memcpy(priv->frame, event->data, length);
 	}
 
