@@ -4,8 +4,7 @@
 
 #include <glib.h>
 #include <glib-object.h>
-#include "fw_unit.h"
-#include "hinawa_enum_types.h"
+#include <hinawa_enums.h>
 
 G_BEGIN_DECLS
 
@@ -49,19 +48,9 @@ GType hinawa_fw_req_get_type(void) G_GNUC_CONST;
 
 HinawaFwReq *hinawa_fw_req_new(void);
 
-void hinawa_fw_req_write(HinawaFwReq *self, HinawaFwUnit *unit, guint64 addr,
-			 GByteArray *frame, GError **exception);
-
-void hinawa_fw_req_read(HinawaFwReq *self, HinawaFwUnit *unit, guint64 addr,
-			GByteArray *frame, guint length, GError **exception);
-
-void hinawa_fw_req_lock(HinawaFwReq *self, HinawaFwUnit *unit, guint64 addr,
-			GByteArray **frame, HinawaFwTcode lock_tcode,
-			GError **exception);
-
 void hinawa_fw_req_transaction(HinawaFwReq *self, HinawaFwNode *node,
-			       HinawaFwTcode tcode, guint64 addr, guint length,
-			       guint8 *const *frame, guint *frame_size,
+			       HinawaFwTcode tcode, guint64 addr, gsize length,
+			       guint8 *const *frame, gsize *frame_size,
 			       GError **exception);
 
 G_END_DECLS
