@@ -4,7 +4,6 @@
 
 #include <glib.h>
 #include <glib-object.h>
-#include "fw_unit.h"
 #include "hinawa_enums.h"
 
 G_BEGIN_DECLS
@@ -68,14 +67,10 @@ void hinawa_fw_resp_reserve(HinawaFwResp *self, HinawaFwNode*node,
 			    guint64 addr, guint width, GError **exception);
 void hinawa_fw_resp_release(HinawaFwResp *self);
 
-void hinawa_fw_resp_register(HinawaFwResp *self, HinawaFwUnit *unit,
-			     guint64 addr, guint width, GError **exception);
-void hinawa_fw_resp_unregister(HinawaFwResp *self);
-
 void hinawa_fw_resp_get_req_frame(HinawaFwResp *self, const guint8 **frame,
-				  guint *length);
+				  gsize *length);
 void hinawa_fw_resp_set_resp_frame(HinawaFwResp *self, guint8 *frame,
-				   guint length);
+				   gsize length);
 
 G_END_DECLS
 
