@@ -44,8 +44,8 @@ static void hinawa_snd_dg00x_class_init(HinawaSndDg00xClass *klass)
 			     G_SIGNAL_RUN_LAST,
 			     G_STRUCT_OFFSET(HinawaSndDg00xClass, message),
 			     NULL, NULL,
-			     g_cclosure_marshal_VOID__ULONG,
-			     G_TYPE_NONE, 1, G_TYPE_ULONG);
+			     g_cclosure_marshal_VOID__UINT,
+			     G_TYPE_NONE, 1, G_TYPE_UINT);
 }
 
 static void hinawa_snd_dg00x_init(HinawaSndDg00x *self)
@@ -91,30 +91,13 @@ void hinawa_snd_dg00x_open(HinawaSndDg00x *self, gchar *path, GError **exception
 	}
 }
 
-static void snd_dg00x_notify_msg(void *target, void *data, unsigned int length)
+void hinawa_snd_dg00x_handle_msg(HinawaSndDg00x *self, const void *buf,
+				 ssize_t len)
 {
-	HinawaSndDg00x *self = target;
-	struct snd_firewire_event_digi00x_message *event = data;
+	const struct snd_firewire_event_digi00x_message *event = buf;
+
+	g_return_if_fail(HINAWA_IS_SND_DG00X(self));
 
 	g_signal_emit(self, dg00x_sigs[DG00X_SIG_TYPE_MESSAGE], 0,
 		      event->message);
 }
-
-void hinawa_snd_dg00x_handle_msg(HinawaSndDg00x *self, const void *buf,
-				 unsigned int len)
-{
-	gboolean listening;
-	int err = 0;
-
-	g_return_if_fail(HINAWA_IS_SND_DG00X(self));
-
-	// For backward compatibility.
-	g_object_get(&self->parent_instance, "listening", &listening, NULL);
-	if (listening) {
-		hinawa_context_schedule_notification(self, buf, len,
-					     snd_dg00x_notify_msg, &err);
-		return;
-	}
-
-	snd_dg00x_notify_msg(self, (void *)buf, len);
-}
