@@ -70,8 +70,8 @@ static void hinawa_snd_dice_class_init(HinawaSndDiceClass *klass)
 			     G_SIGNAL_RUN_LAST,
 			     G_STRUCT_OFFSET(HinawaSndDiceClass, notified),
 			     NULL, NULL,
-			     g_cclosure_marshal_VOID__ULONG,
-			     G_TYPE_NONE, 1, G_TYPE_ULONG);
+			     g_cclosure_marshal_VOID__UINT,
+			     G_TYPE_NONE, 1, G_TYPE_UINT);
 }
 
 static void hinawa_snd_dice_init(HinawaSndDice *self)
@@ -144,9 +144,8 @@ void hinawa_snd_dice_transaction(HinawaSndDice *self, guint64 addr,
 				 guint32 bit_flag, GError **exception)
 {
 	HinawaSndDicePrivate *priv;
-	HinawaSndUnit *unit;
 	HinawaFwTcode tcode;
-	unsigned int length;
+	gsize length;
 	guint8 *req_frame;
 	HinawaFwNode *node;
 	gint i;
@@ -187,8 +186,7 @@ void hinawa_snd_dice_transaction(HinawaSndDice *self, guint64 addr,
 
 	// NOTE: I believe that a pair of this action/subaction is done within
 	// default timeout of HinawaFwReq.
-	unit = &self->parent_instance;
-	hinawa_fw_unit_get_node(&unit->parent_instance, &node);
+	hinawa_snd_unit_get_node(&self->parent_instance, &node);
 	hinawa_fw_req_transaction(priv->req, node, tcode, addr, length,
 				  &req_frame, &length, exception);
 	g_free(req_frame);
@@ -208,48 +206,14 @@ end:
 	g_cond_clear(&waiter.cond);
 }
 
-/**
- * hinawa_snd_dice_transact:
- * @self: A #HinawaSndDice
- * @addr: A destination address of target device
- * @frame: (element-type guint32) (array) (in): a 32bit array
- * @bit_flag: bit flag to wait
- * @exception: A #GError
- *
- * Execute write transactions to the given address, then wait and check
- * notification.
- *
- * Deprecated: 1.4: Use hinawa_snd_dice_transaction(), instead.
- */
-void hinawa_snd_dice_transact(HinawaSndDice *self, guint64 addr, GArray *frame,
-			      guint32 bit_flag, GError **exception)
-{
-	hinawa_snd_dice_transaction(self, addr,
-				    (const guint32 *)frame->data, frame->len,
-				    bit_flag, exception);
-}
-
-static void snd_dice_notify_notification(void *target, void *data,
-					 unsigned int length)
-{
-	HinawaSndDice *self = target;
-	struct snd_firewire_event_dice_notification *event = data;
-
-	g_signal_emit(self, dice_sigs[DICE_SIG_TYPE_NOTIFIED],
-		      0, event->notification);
-}
-
 void hinawa_snd_dice_handle_notification(HinawaSndDice *self,
-					 const void *buf, unsigned int len)
+					 const void *buf, ssize_t len)
 {
 	const struct snd_firewire_event_dice_notification *event =
 			(struct snd_firewire_event_dice_notification *)buf;
 	HinawaSndDicePrivate *priv;
 	GList *entry;
 	struct notification_waiter *waiter;
-	gboolean listening;
-	int err = 0;
-
 
 	g_return_if_fail(HINAWA_IS_SND_DICE(self));
 	priv = hinawa_snd_dice_get_instance_private(self);
@@ -266,13 +230,6 @@ void hinawa_snd_dice_handle_notification(HinawaSndDice *self,
 
 	g_mutex_unlock(&priv->mutex);
 
-	// For backward compatibility.
-	g_object_get(&self->parent_instance, "listening", &listening, NULL);
-	if (listening) {
-		hinawa_context_schedule_notification(self, buf, len,
-					snd_dice_notify_notification, &err);
-		return;
-	}
-
-	snd_dice_notify_notification(self, (void *)buf, len);
+	g_signal_emit(self, dice_sigs[DICE_SIG_TYPE_NOTIFIED],
+		      0, event->notification);
 }
