@@ -51,7 +51,7 @@ struct _HinawaSndDiceClass {
 	 * When Dice models transfer notification, the ::notified handler is
 	 * called.
 	 */
-	void (*notified)(HinawaSndDice *self, gulong message);
+	void (*notified)(HinawaSndDice *self, guint message);
 };
 
 GType hinawa_snd_dice_get_type(void) G_GNUC_CONST;
@@ -64,9 +64,6 @@ void hinawa_snd_dice_transaction(HinawaSndDice *self, guint64 addr,
 			         const guint32 *frame, gsize frame_count,
 				 guint32 bit_flag, GError **exception);
 
-void hinawa_snd_dice_transact(HinawaSndDice *self, guint64 addr, GArray *frame,
-			      guint32 bit_flag, GError **exception);
-
 G_END_DECLS
 
 #endif
