@@ -47,8 +47,8 @@ static void hinawa_snd_motu_class_init(HinawaSndMotuClass *klass)
 			     G_SIGNAL_RUN_LAST,
 			     G_STRUCT_OFFSET(HinawaSndMotuClass, notified),
 			     NULL, NULL,
-			     g_cclosure_marshal_VOID__ULONG,
-			     G_TYPE_NONE, 1, G_TYPE_ULONG);
+			     g_cclosure_marshal_VOID__UINT,
+			     G_TYPE_NONE, 1, G_TYPE_UINT);
 }
 
 static void hinawa_snd_motu_init(HinawaSndMotu *self)
@@ -94,31 +94,13 @@ void hinawa_snd_motu_open(HinawaSndMotu *self, gchar *path, GError **exception)
 	}
 }
 
-static void snd_motu_notify_notification(void *target, void *data,
-					 unsigned int length)
+void hinawa_snd_motu_handle_notification(HinawaSndMotu *self,
+					 const void *buf, ssize_t len)
 {
-	HinawaSndMotu *self = target;
-	struct snd_firewire_event_motu_notification *event = data;
+	const struct snd_firewire_event_motu_notification *event = buf;
+
+	g_return_if_fail(HINAWA_IS_SND_MOTU(self));
 
 	g_signal_emit(self, motu_sigs[MOTU_SIG_TYPE_NOTIFIED], 0,
 		      event->message);
 }
-
-void hinawa_snd_motu_handle_notification(HinawaSndMotu *self,
-					 const void *buf, unsigned int len)
-{
-	gboolean listening;
-	int err = 0;
-
-	g_return_if_fail(HINAWA_IS_SND_MOTU(self));
-
-	// For backward compatibility.
-	g_object_get(&self->parent_instance, "listening", &listening, NULL);
-	if (listening) {
-		hinawa_context_schedule_notification(self, buf, len,
-					snd_motu_notify_notification, &err);
-		return;
-	}
-
-	snd_motu_notify_notification(self, (void *)buf, len);
-}
