@@ -4,7 +4,6 @@
 
 #include <glib.h>
 #include <glib-object.h>
-#include "fw_unit.h"
 
 G_BEGIN_DECLS
 
@@ -35,13 +34,13 @@ typedef struct _HinawaSndUnitClass	HinawaSndUnitClass;
 typedef struct _HinawaSndUnitPrivate	HinawaSndUnitPrivate;
 
 struct _HinawaSndUnit {
-	HinawaFwUnit parent_instance;
+	GObject parent_instance;
 
 	HinawaSndUnitPrivate *priv;
 };
 
 struct _HinawaSndUnitClass {
-	HinawaFwUnitClass parent_class;
+	GObjectClass parent_class;
 
 	/**
 	 * HinawaSndUnitClass::lock_status:
@@ -52,6 +51,17 @@ struct _HinawaSndUnitClass {
 	 * handler is called.
 	 */
 	void (*lock_status)(HinawaSndUnit *self, gboolean state);
+
+	/**
+	 * HinawaSndUnitClass::disconnected:
+	 * @self: A #HinawaSndUnit
+	 *
+	 * When the sound card is not available anymore due to unbinding driver
+	 * or hot unplugging, this signal is emit. The owner of this object
+	 * should call g_object_free() as quickly as possible to release ALSA
+	 * hwdep character device.
+	 */
+	void (*disconnected)(HinawaSndUnit *self);
 };
 
 GType hinawa_snd_unit_get_type(void) G_GNUC_CONST;
@@ -60,12 +70,11 @@ HinawaSndUnit *hinawa_snd_unit_new(void);
 
 void hinawa_snd_unit_open(HinawaSndUnit *self, gchar *path, GError **exception);
 
+void hinawa_snd_unit_get_node(HinawaSndUnit *self, HinawaFwNode **node);
+
 void hinawa_snd_unit_lock(HinawaSndUnit *self, GError **exception);
 void hinawa_snd_unit_unlock(HinawaSndUnit *self, GError **exception);
 
-void hinawa_snd_unit_listen(HinawaSndUnit *self, GError **exception);
-void hinawa_snd_unit_unlisten(HinawaSndUnit *self);
-
 void hinawa_snd_unit_create_source(HinawaSndUnit *self, GSource **gsrc,
 				   GError **exception);
 
